==> v1.0.0.tar.gz: platomix-gmetry-bi/platomix-gmetry-bi-api/src/main/java/org/springblade/usergroup/task/DefineGroupJobHandler.java <==
package org.springblade.usergroup.task;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;
import java.util.stream.Collectors;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.BladeUser;
import org.springblade.core.tool.api.R;
import org.springblade.cube.enums.ViewColumnTypeEnum;
import org.springblade.cube.model.CubeData;
import org.springblade.cube.model.FileStructure;
import org.springblade.cube.service.DynamicTableService;
import org.springblade.cube.utils.CubeUtils;
import org.springblade.report.entity.ReportDatasource;
import org.springblade.usergroup.dto.ColumnDto;
import org.springblade.usergroup.dto.DefineRuleDto;
import org.springblade.usergroup.entity.DefineGroup;
import org.springblade.usergroup.service.DefineGroupService;
import org.springblade.usergroup.service.ExecuteClickService;
import org.springblade.visual.dto.ComponentColumn;
import org.springblade.visual.dto.QuerySqlParam;
import org.springblade.visual.service.QuerySqlService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.xxl.job.core.biz.AdminBiz;
import com.xxl.job.core.biz.client.AdminBizClient;
import com.xxl.job.core.context.XxlJobHelper;
import com.xxl.job.core.handler.annotation.XxlJob;

import cn.hutool.core.date.DateUtil;

@Component
public class DefineGroupJobHandler {
	private final static Logger logger = LoggerFactory.getLogger(DefineGroupJobHandler.class);

	@Autowired
	private DynamicTableService dynamicTableService;

	@Autowired
	private DefineGroupService defineGroupService;

	@Autowired
	private QuerySqlService querySqlService;

	@Autowired
	private ExecuteClickService executeClickService;


	@Value("${xxl.job.admin.addresses}")
	private String addressUrl;

	@Value("${xxl.job.accessToken}")
	private String accessToken;


	@XxlJob("defineGroupJobHandler")
	public void defineGroupJobHandler() {
		// 获取参数
		String param = XxlJobHelper.getJobParam();
//		String[] methodParams = param.split(",");
//		logger.info("defineGroupId..[{}]", methodParams[0]);
		//控制台输出日志
		logger.info("defineGroupJobHandler execute...");
		//保存数据集过滤器解析后的结果
    	List<QuerySqlParam> sqlList= new ArrayList<>();
		Integer defineGroupId=Integer.valueOf(param);
		DefineGroup defineGroup= defineGroupService.getById(defineGroupId);
		try {
			if (defineGroup != null && defineGroup.getStatus() != 1){
				//状态置为计算中
				defineGroup.setStatus(1);
				defineGroupService.updateById(defineGroup);

				//根据请求频率生成分区字段值
				Long value =formatFreq(defineGroup.getRequestFreq());

				BladeUser bladeUser=new BladeUser();
				bladeUser.setUserId(defineGroup.getCreateUserId());
				List<DefineRuleDto> ruleDtoList = JSON.parseArray(defineGroup.getDefineRule(), DefineRuleDto.class);
				if (ruleDtoList != null && ruleDtoList.size() > 0) {
					for (int i = 0; i < ruleDtoList.size(); i++) {
						//解析sql
						R<QuerySqlParam> r = querySqlService.parseDefineGroupQuerySql(ruleDtoList.get(i).getCubeId(), ruleDtoList.get(i), bladeUser);
						sqlList.add(r.getData());
					}
				}
				if (sqlList.size()>0){
					List<Callable<JSONObject>> callList = new ArrayList<>();
					for (QuerySqlParam sqlParam : sqlList){
						Callable<JSONObject> sqlParamCallable =new Callable() {
							@Override
							public JSONObject call() throws Exception {
								//处理sql
								return dealQuerySqlParam(defineGroupId,value,sqlParam);
							}
						};
						callList.add(sqlParamCallable);
					}
					//创建线程池
					ExecutorService executorService = Executors.newFixedThreadPool(sqlList.size());
					//阻塞执行
					List<Future<JSONObject>> futures = executorService.invokeAll(callList);
//					futures.forEach(f -> {
//						try {
//							f.get();
//						} catch (InterruptedException | ExecutionException e) {
//							e.printStackTrace();
//						}
//					});
				}
				//处理查询的数据集结果
				Long count = doResult(defineGroup, value, ruleDtoList, sqlList);
				defineGroup.setAmount(count);
				//状态置为计算完成
				defineGroup.setStatus(2);
				defineGroup.setTimeZone(value.toString());
				defineGroupService.updateById(defineGroup);

				//将requestFreq=1的任务暂停
				if (defineGroup.getRequestFreq() == 0){
					AdminBiz adminBiz = new AdminBizClient(addressUrl, accessToken);
					adminBiz.jobStop(defineGroup.getJobId());
				}
			}
			//写日志到调度中心日志中
			XxlJobHelper.log("defineGroupJobHandler execute Success...");
			// 设置任务结果
			XxlJobHelper.handleSuccess();
		} catch (Exception e) {
			if (defineGroup != null){
				defineGroup.setStatus(3);
				defineGroupService.updateById(defineGroup);
			}
			logger.error("defineGroupJobHandler execute Fail ...", e);
			//写日志到调度中心日志中
			XxlJobHelper.log("defineGroupJobHandler execute Fail...");
			// 设置任务结果
			XxlJobHelper.handleFail();
		}

	}

	/**
	 * 处理sql过程
	 * @param sqlParam
	 * @return
	 */
	public JSONObject dealQuerySqlParam(Integer defineGroupId,Long the_value,QuerySqlParam sqlParam){

		//分区字段赋值
		ReportDatasource reportDatasource = sqlParam.getReportDatasource();
		CubeData cubeData = sqlParam.getCubeData();
		String querySql = sqlParam.getQuerySql();

		List<ComponentColumn> columnList = new ArrayList<>();
		DefineGroup defineGroup= defineGroupService.getById(defineGroupId);
		String cubeColumns = defineGroup.getCubeColumns();
		List<ColumnDto> columnDtos = JSON.parseArray(cubeColumns, ColumnDto.class);
		for(ColumnDto columnDto: columnDtos){
			if (columnDto.getCubeId().equals(cubeData.getId())){
				columnList=columnDto.getColumns();
			}
		}

//		List<JSONObject>reList= new ArrayList<>();
//		List<ComponentColumn> columnList =sqlParam.getColumnList();
		//组装插入sql
		String insertSql="";
		//存放字段数据类型
		Map<Integer, ViewColumnTypeEnum>headerMap = new HashMap<>();
		//存放字段名称
		Map<Integer, String>columnMap = new HashMap<>();
		if (columnList !=null  && columnList.size()>0) {
			List<FileStructure> structureList = new ArrayList<>();
			for (int i = 0; i < columnList.size(); i++) {
				FileStructure fileStructure = new FileStructure();
//				if (StringUtil.isBlank(columnList.get(i).getColumnName()) && StringUtil.isNotBlank(columnList.get(i).getColumnAliasName())){
//					columnList.get(i).setColumnName(columnList.get(i).getColumnAliasName());
//				}
				fileStructure.setColumnName(columnList.get(i).getUserGroupColumnAliasName());
				fileStructure.setColumnType(columnList.get(i).getViewDataType());
				//暂时把字段别名放到注释上
				fileStructure.setComment(columnList.get(i).getColumnAliasName());
				fileStructure.setColumnIndex(i);
				structureList.add(fileStructure);
			}
			headerMap = structureList.stream().collect(Collectors.toMap(FileStructure::getColumnIndex, FileStructure::getColumnType));
			columnMap = structureList.stream().collect(Collectors.toMap(FileStructure::getColumnIndex, FileStructure::getComment));
			structureList.add(new FileStructure("the_value", ViewColumnTypeEnum.NUMBER, "分区字段", structureList.size()));
			insertSql = CubeUtils.buildInsertSql("defineGroup_"+defineGroupId+"_"+cubeData.getId(), structureList);
		}
		//分页循环查询
		int i=1;
		Query query = new Query();
		query.setSize(3000);
		while (true){
			query.setCurrent(i);
			List<Map<String, Object>> dataList = dynamicTableService.selectPageList(Condition.getPage(query),reportDatasource, querySql);
			if (dataList!= null && dataList.size()>0){
				for(Map<String, Object> object : dataList){
					object.put("the_value",the_value);
				}
				//批量入库
				executeClickService.batchSave(insertSql,headerMap,columnMap,dataList);
//				reList.addAll(dataList);
				i++;
			}else {
				break;
			}

		}
		return null;
	}


	/**
	 * 处理数据集之间交并差
	 * @param defineGroup
	 * @param formatFreq
	 * @param ruleDtoList
	 */
	public Long doResult(DefineGroup defineGroup,Long formatFreq,List<DefineRuleDto> ruleDtoList,List<QuerySqlParam> sqlList){
		if (ruleDtoList != null){
			List<ColumnDto> columnDtoList = JSON.parseArray(defineGroup.getCubeColumns(), ColumnDto.class);
			Map<Integer, List<ComponentColumn>> map = columnDtoList.stream().collect(Collectors.toMap(ColumnDto::getCubeId,ColumnDto::getColumns));
			StringBuilder sql = new StringBuilder();
			StringBuilder countSql = new StringBuilder();
			sql.append(String.format("insert into %s (",defineGroup.getResultTable()));

			countSql.append("select count(1) ");
			StringBuilder selectSql = new StringBuilder();
			StringBuilder conditionSql = new StringBuilder();
			StringBuilder whereSql = new StringBuilder();
			selectSql.append("select ");
			whereSql.append("where");
			String a_userGroupColumnAliasName=map.get(ruleDtoList.get(0).getCubeId()).get(0).getUserGroupColumnAliasName();
			for(int i=0;i<ruleDtoList.size();i++){
				String tableAliasName=String.valueOf((char)(i+97));
				List<ComponentColumn> columnList=map.get(ruleDtoList.get(i).getCubeId());
				//从map中取
				for (int j=0;j<columnList.size();j++){
					if ( (i>0 && j!=0) || (i==0)){
						sql.append(String.format("%s ,",columnList.get(j).getUserGroupColumnAliasName()));
						selectSql.append(String.format("%s.%s as %s ,",tableAliasName,columnList.get(j).getUserGroupColumnAliasName(),columnList.get(j).getUserGroupColumnAliasName()));
					}
				}
//				if (i == 0){
//					selectSql.append(String.format("%s.%s as %s ,",tableAliasName,"the_value","the_value"));
//				}
				whereSql.append(String.format(" %s.%s = %s and",tableAliasName,"the_value",formatFreq));

				if (i > 0){
					String connectType = ruleDtoList.get(i).getConnectType();
					if (connectType.equals("or")){//并
						conditionSql.append(String.format(" inner jion %s %s on a.%s = %s.%s ","defineGroup_"+defineGroup.getId()+"_"+ruleDtoList.get(i).getCubeId(),tableAliasName,a_userGroupColumnAliasName,tableAliasName,columnList.get(0).getUserGroupColumnAliasName()));
					}else if (connectType.equals("and")){//交
						conditionSql.append(String.format(" full outer join %s %s on a.%s = %s.%s ","defineGroup_"+defineGroup.getId()+"_"+ruleDtoList.get(i).getCubeId(),tableAliasName,a_userGroupColumnAliasName,tableAliasName,columnList.get(0).getUserGroupColumnAliasName()));
					}else if (connectType.equals("del")){//差
						conditionSql.append(String.format(" full outer join %s %s on a.%s = %s.%s ","defineGroup_"+defineGroup.getId()+"_"+ruleDtoList.get(i).getCubeId(),tableAliasName,a_userGroupColumnAliasName,tableAliasName,columnList.get(0).getUserGroupColumnAliasName()));
						whereSql.append(String.format("a.%s is null or %s.%s is null and",a_userGroupColumnAliasName,tableAliasName,columnList.get(0).getUserGroupColumnAliasName()));
					}
				}

			}
			selectSql.append("a.the_value as the_value");

			//拼接from语句
			selectSql.append(String.format(" from %s %s ", "defineGroup_"+defineGroup.getId()+"_"+ruleDtoList.get(0).getCubeId(),"a"));
			countSql.append(String.format(" from %s %s ", "defineGroup_"+defineGroup.getId()+"_"+ruleDtoList.get(0).getCubeId(),"a"));
			//去掉最后一个and
			sql.append("the_value) ").append(selectSql).append(conditionSql).append(whereSql.substring(0,whereSql.length() - 3));
			countSql.append(conditionSql).append(whereSql.substring(0,whereSql.length() - 3));
			//执行sql
			executeClickService.executeSql(sql.toString());
			return executeClickService.selectCount(countSql.toString());
		}
		return 0L;
	}

	public Long formatFreq(Integer requestFreq){
		Date date =new Date();
		if (requestFreq == 0){
			return Long.valueOf(DateUtil.format(date, "yyyyMMddHHmm"));
		}else if (requestFreq == 1){
			return Long.valueOf(DateUtil.format(date, "yyyyMMdd"));
		}else if (requestFreq == 2){
			return Long.valueOf(DateUtil.format(date, "yyyyMMdd"));
		}else if (requestFreq == 3){
			return Long.valueOf(DateUtil.format(date, "yyyyMM"));
		}
	return null;
	}
}

==> v1.1.1.tar.gz: platomix-gmetry-bi/platomix-gmetry-bi-api/src/main/java/org/springblade/usergroup/task/DefineGroupJobHandler.java <==
package org.springblade.usergroup.task;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;
import java.util.stream.Collectors;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.BladeUser;
import org.springblade.core.tool.api.R;
import org.springblade.cube.enums.ViewColumnTypeEnum;
import org.springblade.cube.model.CubeData;
import org.springblade.cube.model.FileStructure;
import org.springblade.cube.service.DynamicTableService;
import org.springblade.cube.utils.CubeUtils;
import org.springblade.report.entity.ReportDatasource;
import org.springblade.usergroup.dto.ColumnDto;
import org.springblade.usergroup.dto.DefineRuleDto;
import org.springblade.usergroup.entity.DefineGroup;
import org.springblade.usergroup.service.DefineGroupService;
import org.springblade.usergroup.service.ExecuteClickService;
import org.springblade.visual.dto.ComponentColumn;
import org.springblade.visual.dto.QuerySqlParam;
import org.springblade.visual.service.DefineGroupSqlService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.xxl.job.core.biz.AdminBiz;
import com.xxl.job.core.biz.client.AdminBizClient;
import com.xxl.job.core.context.XxlJobHelper;
import com.xxl.job.core.handler.annotation.XxlJob;

import cn.hutool.core.date.DateUtil;

@Component
public class DefineGroupJobHandler {
	private final static Logger logger = LoggerFactory.getLogger(DefineGroupJobHandler.class);

	@Autowired
	private DynamicTableService dynamicTableService;

	@Autowired
	private DefineGroupService defineGroupService;

	@Autowired
	private DefineGroupSqlService querySqlService;

	@Autowired
	private ExecuteClickService executeClickService;


	@Value("${xxl.job.admin.addresses}")
	private String addressUrl;

	@Value("${xxl.job.accessToken}")
	private String accessToken;


	@XxlJob("defineGroupJobHandler")
	public void defineGroupJobHandler() {
		// 获取参数
		String param = XxlJobHelper.getJobParam();
//		String[] methodParams = param.split(",");
//		logger.info("defineGroupId..[{}]", methodParams[0]);
		//控制台输出日志
		logger.info("defineGroupJobHandler execute...");
		//保存数据集过滤器解析后的结果
    	List<QuerySqlParam> sqlList= new ArrayList<>();
		Integer defineGroupId=Integer.valueOf(param);
		DefineGroup defineGroup= defineGroupService.getById(defineGroupId);
		try {
			if (defineGroup != null && defineGroup.getStatus() != 1){
				//状态置为计算中
				defineGroup.setStatus(1);
				defineGroupService.updateById(defineGroup);

				//根据请求频率生成分区字段值
				Long value =formatFreq(defineGroup.getRequestFreq());

				BladeUser bladeUser=new BladeUser();
				bladeUser.setUserId(defineGroup.getCreateUserId());
				List<DefineRuleDto> ruleDtoList = JSON.parseArray(defineGroup.getDefineRule(), DefineRuleDto.class);
				if (ruleDtoList != null && ruleDtoList.size() > 0) {
					for (int i = 0; i < ruleDtoList.size(); i++) {
						//解析sql
						R<QuerySqlParam> r = querySqlService.parseDefineGroupQuerySql(ruleDtoList.get(i).getCubeId(), ruleDtoList.get(i), bladeUser);
						sqlList.add(r.getData());
					}
				}
				if (sqlList.size()>0){
					List<Callable<JSONObject>> callList = new ArrayList<>();
					for (QuerySqlParam sqlParam : sqlList){
						Callable<JSONObject> sqlParamCallable =new Callable() {
							@Override
							public JSONObject call() throws Exception {
								//处理sql
								return dealQuerySqlParam(defineGroupId,value,sqlParam);
							}
						};
						callList.add(sqlParamCallable);
					}
					//创建线程池
					ExecutorService executorService = Executors.newFixedThreadPool(sqlList.size());
					//阻塞执行
					List<Future<JSONObject>> futures = executorService.invokeAll(callList);
//					futures.forEach(f -> {
//						try {
//							f.get();
//						} catch (InterruptedException | ExecutionException e) {
//							e.printStackTrace();
//						}
//					});
				}
				//处理查询的数据集结果
				Long count = doResult(defineGroup, value, ruleDtoList, sqlList);
				defineGroup.setAmount(count);
				//状态置为计算完成
				defineGroup.setStatus(2);
				defineGroup.setTimeZone(value.toString());
				defineGroupService.updateById(defineGroup);

				//将requestFreq=1的任务暂停
				if (defineGroup.getRequestFreq() == 0){
					AdminBiz adminBiz = new AdminBizClient(addressUrl, accessToken);
					adminBiz.jobStop(defineGroup.getJobId());
				}
			}
			//写日志到调度中心日志中
			XxlJobHelper.log("defineGroupJobHandler execute Success...");
			// 设置任务结果
			XxlJobHelper.handleSuccess();
		} catch (Exception e) {
			if (defineGroup != null){
				defineGroup.setStatus(3);
				defineGroupService.updateById(defineGroup);
			}
			logger.error("defineGroupJobHandler execute Fail ...", e);
			//写日志到调度中心日志中
			XxlJobHelper.log("defineGroupJobHandler execute Fail...");
			// 设置任务结果
			XxlJobHelper.handleFail();
		}

	}

	/**
	 * 处理sql过程
	 * @param sqlParam
	 * @return
	 */
	public JSONObject dealQuerySqlParam(Integer defineGroupId,Long the_value,QuerySqlParam sqlParam){

		//分区字段赋值
		ReportDatasource reportDatasource = sqlParam.getReportDatasource();
		CubeData cubeData = sqlParam.getCubeData();
		String querySql = sqlParam.getQuerySql();

		List<ComponentColumn> columnList = new ArrayList<>();
		DefineGroup defineGroup= defineGroupService.getById(defineGroupId);
		String cubeColumns = defineGroup.getCubeColumns();
		List<ColumnDto> columnDtos = JSON.parseArray(cubeColumns, ColumnDto.class);
		for(ColumnDto columnDto: columnDtos){
			if (columnDto.getCubeId().equals(cubeData.getId())){
				columnList=columnDto.getColumns();
			}
		}

//		List<JSONObject>reList= new ArrayList<>();
//		List<ComponentColumn> columnList =sqlParam.getColumnList();
		//组装插入sql
		String insertSql="";
		//存放字段数据类型
		Map<Integer, ViewColumnTypeEnum>headerMap = new HashMap<>();
		//存放字段名称
		Map<Integer, String>columnMap = new HashMap<>();
		if (columnList !=null  && columnList.size()>0) {
			List<FileStructure> structureList = new ArrayList<>();
			for (int i = 0; i < columnList.size(); i++) {
				FileStructure fileStructure = new FileStructure();
//				if (StringUtil.isBlank(columnList.get(i).getColumnName()) && StringUtil.isNotBlank(columnList.get(i).getColumnAliasName())){
//					columnList.get(i).setColumnName(columnList.get(i).getColumnAliasName());
//				}
				fileStructure.setColumnName(columnList.get(i).getUserGroupColumnAliasName());
				fileStructure.setColumnType(columnList.get(i).getViewDataType());
				//暂时把字段别名放到注释上
				fileStructure.setComment(columnList.get(i).getColumnAliasName());
				fileStructure.setColumnIndex(i);
				structureList.add(fileStructure);
			}
			headerMap = structureList.stream().collect(Collectors.toMap(FileStructure::getColumnIndex, FileStructure::getColumnType));
			columnMap = structureList.stream().collect(Collectors.toMap(FileStructure::getColumnIndex, FileStructure::getComment));
			structureList.add(new FileStructure("the_value", ViewColumnTypeEnum.NUMBER, "分区字段", structureList.size()));
			insertSql = CubeUtils.buildInsertSql("defineGroup_"+defineGroupId+"_"+cubeData.getId(), structureList);
		}
		//分页循环查询
		int i=1;
		Query query = new Query();
		query.setSize(3000);
		while (true){
			query.setCurrent(i);
			List<Map<String, Object>> dataList = dynamicTableService.selectPageList(Condition.getPage(query),reportDatasource, querySql);
			if (dataList!= null && dataList.size()>0){
				for(Map<String, Object> object : dataList){
					object.put("the_value",the_value);
				}
				//批量入库
				executeClickService.batchSave(insertSql,headerMap,columnMap,dataList);
//				reList.addAll(dataList);
				i++;
			}else {
				break;
			}

		}
		return null;
	}


	/**
	 * 处理数据集之间交并差
	 * @param defineGroup
	 * @param formatFreq
	 * @param ruleDtoList
	 */
	public Long doResult(DefineGroup defineGroup,Long formatFreq,List<DefineRuleDto> ruleDtoList,List<QuerySqlParam> sqlList){
		if (ruleDtoList != null){
			List<ColumnDto> columnDtoList = JSON.parseArray(defineGroup.getCubeColumns(), ColumnDto.class);
			Map<Integer, List<ComponentColumn>> map = columnDtoList.stream().collect(Collectors.toMap(ColumnDto::getCubeId,ColumnDto::getColumns));
			StringBuilder sql = new StringBuilder();
			StringBuilder countSql = new StringBuilder();
			sql.append(String.format("insert into %s (",defineGroup.getResultTable()));

			countSql.append("select count(1) ");
			StringBuilder selectSql = new StringBuilder();
			StringBuilder conditionSql = new StringBuilder();
			StringBuilder whereSql = new StringBuilder();
			selectSql.append("select ");
			whereSql.append("where");
			String a_userGroupColumnAliasName=map.get(ruleDtoList.get(0).getCubeId()).get(0).getUserGroupColumnAliasName();
			for(int i=0;i<ruleDtoList.size();i++){
				String tableAliasName=String.valueOf((char)(i+97));
				List<ComponentColumn> columnList=map.get(ruleDtoList.get(i).getCubeId());
				//从map中取
				for (int j=0;j<columnList.size();j++){
					if ( (i>0 && j!=0) || (i==0)){
						sql.append(String.format("%s ,",columnList.get(j).getUserGroupColumnAliasName()));
						selectSql.append(String.format("%s.%s as %s ,",tableAliasName,columnList.get(j).getUserGroupColumnAliasName(),columnList.get(j).getUserGroupColumnAliasName()));
					}
				}
//				if (i == 0){
//					selectSql.append(String.format("%s.%s as %s ,",tableAliasName,"the_value","the_value"));
//				}
				whereSql.append(String.format(" %s.%s = %s and",tableAliasName,"the_value",formatFreq));

				if (i > 0){
					String connectType = ruleDtoList.get(i).getConnectType();
					if (connectType.equals("or")){//并
						conditionSql.append(String.format(" inner jion %s %s on a.%s = %s.%s ","defineGroup_"+defineGroup.getId()+"_"+ruleDtoList.get(i).getCubeId(),tableAliasName,a_userGroupColumnAliasName,tableAliasName,columnList.get(0).getUserGroupColumnAliasName()));
					}else if (connectType.equals("and")){//交
						conditionSql.append(String.format(" full outer join %s %s on a.%s = %s.%s ","defineGroup_"+defineGroup.getId()+"_"+ruleDtoList.get(i).getCubeId(),tableAliasName,a_userGroupColumnAliasName,tableAliasName,columnList.get(0).getUserGroupColumnAliasName()));
					}else if (connectType.equals("del")){//差
						conditionSql.append(String.format(" full outer join %s %s on a.%s = %s.%s ","defineGroup_"+defineGroup.getId()+"_"+ruleDtoList.get(i).getCubeId(),tableAliasName,a_userGroupColumnAliasName,tableAliasName,columnList.get(0).getUserGroupColumnAliasName()));
						whereSql.append(String.format("a.%s is null or %s.%s is null and",a_userGroupColumnAliasName,tableAliasName,columnList.get(0).getUserGroupColumnAliasName()));
					}
				}

			}
			selectSql.append("a.the_value as the_value");

			//拼接from语句
			selectSql.append(String.format(" from %s %s ", "defineGroup_"+defineGroup.getId()+"_"+ruleDtoList.get(0).getCubeId(),"a"));
			countSql.append(String.format(" from %s %s ", "defineGroup_"+defineGroup.getId()+"_"+ruleDtoList.get(0).getCubeId(),"a"));
			//去掉最后一个and
			sql.append("the_value) ").append(selectSql).append(conditionSql).append(whereSql.substring(0,whereSql.length() - 3));
			countSql.append(conditionSql).append(whereSql.substring(0,whereSql.length() - 3));
			//执行sql
			executeClickService.executeSql(sql.toString());
			return executeClickService.selectCount(countSql.toString());
		}
		return 0L;
	}

	public Long formatFreq(Integer requestFreq){
		Date date =new Date();
		if (requestFreq == 0){
			return Long.valueOf(DateUtil.format(date, "yyyyMMddHHmm"));
		}else if (requestFreq == 1){
			return Long.valueOf(DateUtil.format(date, "yyyyMMdd"));
		}else if (requestFreq == 2){
			return Long.valueOf(DateUtil.format(date, "yyyyMMdd"));
		}else if (requestFreq == 3){
			return Long.valueOf(DateUtil.format(date, "yyyyMM"));
		}
	return null;
	}
}
